@@ -1,6 +1,6 @@
 package Business::CardInfo;
-BEGIN {
-  $Business::CardInfo::VERSION = '0.10';
+{
+  $Business::CardInfo::VERSION = '0.11';
 }
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -55,13 +55,16 @@ sub _build_type {
     407704, 407705, 408367, 445190, 456705, 456706, 474503,
     474551, 475183, 499844 .. 499846, 460024, 421682, 441078, 445191, 445192, 
     458046, 480240, 499806, 484412, 484415 .. 484417, 495065, 495067, 
-    495090 .. 495094, 446291, 446292, 408456, 408457
+    495090 .. 495094, 446291, 446292, 408456, 408457, 459338, 459339,
+    459340, 459362, 459364, 459364, 459389, 459499, 459500, 459501,
+    459511, 459512, 459566, 459567, 459568, 489342, 459600 .. 459799
   ]);
   return "Visa Electron" if $self->_search([
     417500, 400115, 400837 .. 400839, 412921 .. 412923, 417935, 419740, 
-    419741, 419773 .. 419775, 424519, 424962, 424963, 444000,
+    419741, 419773 .. 419776, 424519, 424962, 424963, 444000,
     484428 .. 484455, 491730 .. 491759, 491880, 4917, 4913,
-    4508, 4844,  484406 .. 484411, 484413, 484414, 484418 .. 484426]);
+    4508, 4844,  484406 .. 484411, 484413, 484414, 484418 .. 484426,
+    437860, 459472]);
   return "MasterCard Debit" if $self->_search([
     512499, 512746, 516001, 516730, 516979, 517000, 517049, 524342, 527591,
     535110 .. 535309, 535420 .. 535819, 537210 .. 537609, 557347 .. 557496,
@@ -107,7 +110,7 @@ Business::CardInfo - Get/Validate data from credit & debit cards
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -198,4 +201,4 @@ L<http://search.cpan.org/dist/Business-CardInfo>
 
 =cut
 
-1;
\ No newline at end of file
+1;
